# -*- coding: iso-8859-1 -*-
# vim: set ft=python ts=3 sw=3 expandtab:
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
#              C E D A R
#          S O L U T I O N S       "Software done right."
#           S O F T W A R E
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Author   : Kenneth J. Pronovici <pronovic@ieee.org>
# Language : Python (>= 2.3)
# Project  : Cedar Backup, release 2
# Revision : $Id: release.py 926 2008-10-06 02:39:19Z pronovic $
# Purpose  : Provides location to maintain release information.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

"""
Provides location to maintain version information.

@sort: AUTHOR, EMAIL, COPYRIGHT, VERSION, DATE, URL

@var AUTHOR: Author of software.
@var EMAIL: Email address of author.
@var COPYRIGHT: Copyright date.
@var VERSION: Software version.
@var DATE: Software release date.
@var URL: URL of Cedar Backup webpage.

@author: Kenneth J. Pronovici <pronovic@ieee.org>
"""

AUTHOR      = "Kenneth J. Pronovici"
EMAIL       = "pronovic@ieee.org"
COPYRIGHT   = "2004-2008"
VERSION     = "2.19.0"
DATE        = "05 Oct 2008"
URL         = "http://cedar-backup.sourceforge.net/"

